@@ -83,6 +83,16 @@ class imbot:
                     hexor().c(text,"#299c52")
                     get_list.append(eval(xxx))
                     sleep(self.sleep_time)
+                #
+                elif operation['opt']=="sleep":
+                    #
+                    if "arg_data" in operation:
+                        data=argm[int(operation['arg_data'])]
+                    elif "data" in operation:
+                        data=operation['data']
+                    else:
+                        data=input(hexor(True).c("Data is empty : ","#ff0000"))
+                    sleep(data)
             #
             except Exception as e:
                 try:
@@ -114,4 +124,4 @@ class imbot:
         print(ascii.asciitext(font_url,"#imbot","#ff0000"))
         hexor().c("https://github.com/yasserbdj96","#299c52")
         print("")
-#}END.
\ No newline at end of file
+#}END.
